EnvConfig class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

isApiDebug bool
Возвращает флаг отладки API
no setter
isRouterDebug bool
Возвращает флаг отладки роутинга
no setter

Static Methods

getEnv<T>(String key, T fallback) → T
Обобщённый метод для получения переменной окружения с возможным значением по умолчанию.
init([String fileName = '.env']) Future<void>
Загружает переменные окружения из файла .env