EnvConstants class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- appMetricaKey → const String
- appStoreAppUrl → const String
- appStoreDeveloperUrl → const String
- bugsnagKey → const String
- developerEmail → const String
- developerSiteUrl → const String
- playStoreAppUrl → const String
- playStoreDeveloperUrl → const String
- privacyPolicyAndroidUrl → const String
- privacyPolicyAppStoreUrl → const String
- ruStoreAppUrl → const String
- ruStoreDeveloperUrl → const String
- siteUrl → const String