AppService class abstract interface

Интерфейс для работы с сервисами приложения.

Определяет контракт для сервисов, предоставляющих функциональность, связанную с информацией о приложении.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fetchAppUrl() Future<String>
Асинхронно получает URL страницы приложения.
fetchDeveloperEmail() Future<String>
Асинхронно получает email разработчика приложения.
fetchDeveloperSiteUrl() Future<String>
Асинхронно получает URL сайта приложения.
fetchDeveloperStoreUrl() Future<String>
Асинхронно получает URL страницы разработчика приложения.
fetchPrivacyPolicyUrl() Future<String>
Асинхронно получает URL политики конфиденциальности приложения.
fetchVersion() Future<String>
Асинхронно получает версию приложения.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited