AppMetricaExceptionService class

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

capture(Object error, StackTrace? stackTrace) Future<void>
Перехватывает исключение и обрабатывает его.
override
init() Future<void>
Инициализирует сервис обработки исключений.
override
markLaunchCompleted() FutureOr<void>
Отмечает, что процесс запуска приложения завершён.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited