AppViewModel mixin
ViewModel для отображения информации о приложении и взаимодействия с внешними ресурсами.
Отвечает за запуск политики конфиденциальности, открытие страницы оценки приложения, переход к другим приложениям разработчика и отправку email.
Properties
- appService → AppService
-
Сервис, предоставляющий данные о приложении (URL политики, URL приложения, email разработчика).
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
launchDeveloperEmail(
) → Future< bool> - Запускает почтовый клиент для отправки email разработчику.
-
launchDeveloperSite(
) → Future< bool> -
launchPrivacyPolicy(
) → Future< bool> - Запускает URL политики конфиденциальности.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rateApp(
) → Future< bool> - Открывает страницу для оценки приложения.
-
seeOtherApps(
) → Future< bool> - Открывает страницу с другими приложениями разработчика.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited