ApiErrorState class

Состояние ошибки API.

Хранит экземпляр ApiException с информацией об ошибке, возникшей при выполнении API-запроса. Применяется для ошибок авторизации или других API-ошибок, не относящихся к плохому запросу.

Inheritance

Constructors

ApiErrorState(ApiException exception)
const

Properties

exception → ApiException
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited