AdvertService class abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
destroyAppOpened(
) → void -
destroyInterstitial(
) → void -
destroyRewarded(
) → void -
init(
Map< String, dynamic> params) → Future<void> -
loadAppOpenAd(
String unitID) → Future< void> -
loadInterstitialAd(
String unitID) → Future< void> -
loadRewardedAd(
String unitID) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setAppOpenListener(
AppOpenListener listener) → void -
setInterstitialListener(
InterstitialListener listener) → void -
setRewardedListener(
RewardedListener listener) → void -
setUserConsent(
bool hasConsent) → void -
showAppOpenAd(
String unitID) → Future< void> -
showInterstitialAd(
String unitID) → Future< void> -
showRewardedAd(
String unitID) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited