BugsnagService class
Сервис для интеграции с Bugsnag для отслеживания и обработки исключений.
Класс BugsnagService реализует интерфейс ExceptionService и обеспечивает:
- Инициализацию Bugsnag с использованием API ключа из переменных окружения.
- Перехват глобальных ошибок Flutter и их отправку в Bugsnag.
- Логирование ошибок с помощью Printer.e.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
capture(
Object exception, StackTrace? stackTrace) → Future< void> -
Перехватывает и обрабатывает исключения.
override
-
init(
) → Future< void> -
Инициализирует сервис Bugsnag.
override
-
markLaunchCompleted(
) → FutureOr< void> -
Отмечает завершение процесса запуска приложения.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited