PaginatorResponse<T> class
Класс, описывающий ответ пагинации.
Содержит информацию о текущей странице, размере страницы, общем количестве элементов и диапазоне элементов на странице.
Constructors
-
PaginatorResponse({required int currentPage, required int lastPage, required int perPage, required int total, required int from, required int to, required List<
T> data}) - Основной конструктор.
-
PaginatorResponse.fromMap(Map<
String, dynamic> json) -
Создает объект PaginatorResponse из Map.
factory
-
PaginatorResponse.unfiled({int currentPage = 1, int lastPage = 1, int perPage = 0, int total = 0, int from = 0, int to = 0, List<
T> data = const []}) - Конструктор для случая, когда данные отсутствуют или не заданы.
Properties
- currentPage → int
-
Номер текущей страницы.
final
-
data
→ List<
T> -
Список элементов текущей страницы.
final
- from → int
-
Индекс первого элемента на странице.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastPage → int
-
Номер последней страницы.
final
- perPage → int
-
Количество элементов на странице.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- to → int
-
Индекс последнего элемента на странице.
final
- total → int
-
Общее количество элементов.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Возвращает строковое представление объекта.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited